飞屋环游记 (豆瓣)
Description: 飞屋环游记电影简介和剧情介绍,飞屋环游记影评、图片、预告片、影讯、论坛、在线购票
Keywords: 飞屋环游记,Up,飞屋环游记影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.35豆瓣电影Top250

# 飞屋环游记 Up (2009)

导演: 彼特·道格特 / 鲍勃·彼德森
编剧: 彼特·道格特 / 鲍勃·彼德森 / 汤姆·麦卡锡
主演: 爱德华·阿斯纳 / 克里斯托弗·普卢默 / 乔丹·长井 / 鲍勃·彼德森 / 德尔罗伊·林多 / 杰罗姆·兰福特 / 约翰·拉岑贝格 / 大卫·卡耶 / 艾丽·道克特 / 杰里米·利里 / 米凯·麦高万 / 丹尼·曼恩 / 唐纳德·富利洛夫 / 杰斯·哈梅尔 / 乔什·库雷 / 彼特·道格特
类型: 剧情 / 喜剧 / 动画 / 冒险
制片国家/地区: 美国
语言: 英语
上映日期: 2009-08-04(中国大陆) / 2009-05-13(戛纳电影节) / 2009-05-29(美国)
片长: 96分钟
又名: 冲天救兵(港) / 天外奇迹(台) / 飞屋历险记
IMDb: tt1049413
豆瓣评分
引用
9.1
1260129人评价
5星
60.7%
4星
32.7%
3星
6.3%
2星
0.3%
1星
0.1%
好于 98% 动画片
好于 98% 冒险片
想看 看过
评价:
推荐

## 飞屋环游记的剧情简介 · · · · · ·

小男孩卡尔（Carl Fredricksen）怀揣着对于冒险的热爱偶遇假小子艾丽（Ellie），而艾丽把整个屋子当成一艘大飞船游戏居然使他对这个女孩子有些着迷，相同的爱好最终使两个人成为了一生的爱侣。
他们有一个梦想，那就是有朝一日要去南美洲的“仙境瀑布”探险，但直到艾丽去世，这个梦想也未能实现。终于有一天，曾经专卖气球的老人卡尔居然用五颜六色的气球拽着他的房子飞上了天空，他决定要去实现他们未曾实现的梦想。令卡尔始料不及的是，门廊居然搭上了一个自称是“荒野开拓者”的小男孩小罗（Russell），小罗的喋喋不休让卡尔对这个小胖墩格外讨厌。
一老一少在飞行中经过了千难万险终于看到了传说中的“仙境瀑布”，在相处过程中卡尔发现小罗其实是个惹人怜爱的孩子。在步行穿越一座森林时，他们遇到了不会飞的大鸟凯文（Kevin）和一只会说话的狗狗逗逗（Dug），让老人惊讶... (展开全部) 小男孩卡尔（Carl Fredricksen）怀揣着对于冒险的热爱偶遇假小子艾丽（Ellie），而艾丽把整个屋子当成一艘大飞船游戏居然使他对这个女孩子有些着迷，相同的爱好最终使两个人成为了一生的爱侣。
他们有一个梦想，那就是有朝一日要去南美洲的“仙境瀑布”探险，但直到艾丽去世，这个梦想也未能实现。终于有一天，曾经专卖气球的老人卡尔居然用五颜六色的气球拽着他的房子飞上了天空，他决定要去实现他们未曾实现的梦想。令卡尔始料不及的是，门廊居然搭上了一个自称是“荒野开拓者”的小男孩小罗（Russell），小罗的喋喋不休让卡尔对这个小胖墩格外讨厌。
一老一少在飞行中经过了千难万险终于看到了传说中的“仙境瀑布”，在相处过程中卡尔发现小罗其实是个惹人怜爱的孩子。在步行穿越一座森林时，他们遇到了不会飞的大鸟凯文（Kevin）和一只会说话的狗狗逗逗（Dug），让老人惊讶的是他们还遇到了他少年的崇拜偶像——探险家查尔斯·蒙兹（Charles Muntz），而且他发现蒙兹居然是一个为达目的不择手段的坏人。这时，老人离自己的梦想之地只有一步之遥……
本片荣获第82届奥斯卡最佳动画长片、最佳配乐2项大奖。 ©豆瓣

## 飞屋环游记的演职员 · · · · · · ( 全部 51 )

- 彼特·道格特 导演
- 鲍勃·彼德森 导演
- 爱德华·阿斯纳 配 卡尔·费迪逊 Carl Fredricksen
- 克里斯托弗·普卢默 配 查尔斯·蒙兹 Charles Muntz
- 乔丹·长井 配 小罗 Russell
- 鲍勃·彼德森 配 小逗 / 发哥 Dug / Alpha

## 飞屋环游记的视频和图片 · · · · · · ( 预告片3 | 添加视频评论 | 图片800 · 添加 )

## 飞屋环游记的获奖情况 · · · · · · ( 全部 )

- 第82届奥斯卡金像奖
- 最佳影片(提名)
- 乔纳斯·里维拉

- 第66届威尼斯电影节
- 未来电影数字奖-特别提及
- 彼特·道格特

- 第67届金球奖
- 电影类 最佳动画长片

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  哈尔的移动城堡

  大闹天宫

  幽灵公主

  风之谷

  怪兽电力公司

  玩具总动员

  冰川时代

  神偷奶爸

  机器人总动员

我要写短评

## 飞屋环游记的短评 · · · · · · ( 全部 207106 条 )

热门 / 最新 / 好友

### 5740 有用 萨萨 看过 2009-07-24 23:40:51

最后那些最无聊的事情，才是我最怀念的。

### 2069 有用 Mr.王™ 看过 2009-07-23 17:19:08

有史以来最强壮的老爷爷和最轻便的房屋~一群最不靠谱的狗和一只引人发笑的怪鸟~外加一位惹人喜爱却戏份不多的老奶奶，组成了一部我大爱的好片！

### 1974 有用 momo 看过 2016-09-10 21:25:01

最让我感动的是电影开头，这对夫妻志趣相投、相濡以沫，我想自己能不能找到这样的另一半呢

### 5412 有用 hua 看过 2009-05-09 18:17:08

我心中的结局：就在老爷爷被勒令搬进养老院的第二天，来接他的人发现老爷爷静静地坐在椅子上，手中拿着还没充完的气球。他已经死了，脸上留着幸福的笑容。飞屋冒险只是老爷爷死前的幻境。至此影片结束。

### 2572 有用 Orchid 看过 2009-05-13 21:55:23

“我总是记得那些无聊的小事情……”“感谢你给了我精彩的一生”，简单并深情着

> 更多短评 207106条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 飞屋环游记的影评 · · · · · · ( 全部 3065 条 )

热门 / 最新 / 好友
Mia 2009-06-19 15:02:47

## 最华丽的冒险是与你相守

这篇影评可能有剧透

其实正片开始前放映的动画短片Partly Cloudy已经让我流泪了一次。当被摧残得羽毛都不剩几根的大鸟最终还是回到孤独乖僻的乌云身边时，我不禁鼻子一酸。而几秒种后，全副武装的大鸟还是被乌云变出的电鳗再次摧残，看到这里的我又大笑起来。这么一笑倒好，先前勉强忍住的眼泪全... (展开)
9256 117 1050回应 收起
暖言巷陌 2009-06-14 19:52:05

## 屋外流水落花，梦暖如昔

(一)About love：银字筝调，心字香烧 或许你会想起我，就像想起一朵不重开的花朵 ——叶赛宁 那个屋子永远不会衰老，它站在瀑布边站成了回忆时的美好与自然的注脚。 Pixar反复刻画的声色是我们遥遥在望的日暮和未曾来临的清晨。影片开头的十几分钟就已经泪流满面，只觉得平... (展开)
2110 117 319回应 收起
Ju~曬太陽小姐 2009-08-08 21:23:20

## 你是我一生的冒险

你相信爱情吗？ 我相信你。 是什么时候我们开始不相信爱情，是什么时候我们开始不敢谈论天长地久，是什么时候我们对物质的崇拜剥离了对爱情本身的信仰。我们习惯的进入或退出一场又一场的恋爱，然后把它当作是爱情的练习。我们的世界太过浮躁，浮躁到没有心去认认真真的经营一... (展开)
2097 66 300回应 收起
赝造的孔方兄 2009-06-17 09:02:10

## Up 回忆是一座囚牢，只有爱能赦免

一直以为长大最重要的过程之一就是接受那些让人失望的现实：政治制度不完善，经济制度不合理，永远学不会到院子里方便的宠物和遍地鬼迷心窍的人，当然还有生得不够聪明不够帅的自己。从这个角度讲，Pixar是个彻头彻尾的童话工厂。不管是它电影内容的天真理想还是这十几年不衰的... (展开)
1173 23 159回应 收起
路小北 2009-08-05 10:24:17

## 我只是难过不能陪你一起老

灯光暗下去，银幕亮起来，我的左手边是一片黑暗。 看银幕中那一对两小无猜慢慢变老，一起搭建那个叫做家的小木屋，一起经营小小的气球生意，一起为了梦想中的旅行攒钱，又一起为了一些不得不面对的困难一次一次打碎那个盛装梦想的罐子，却始终微笑面对，从来也不曾放开手。有爱... (展开)
919 41 249回应 收起
或许 2009-07-16 12:19:15

## 我记得天空倒映在你的眸间

这篇影评可能有剧透

给我九十分钟时间，让我好好想一想。 我不记得怎么样和你熟悉起来， 但我记得我们怎么相识。 我不记得我们的恋爱， 但我记得你身穿白纱，与我交换戒指的瞬间。 我不记得辛苦努力的积攒， 但我记得我们怎样把新房装点， 有我们不同风格却相互依靠的座椅， 有你在我心里最美时... (展开)
522 25 127回应 收起
夏笳 2009-08-09 09:49:28

## 那最初十五分钟的美丽

前十五分钟是神作，看得我热泪盈眶，你以为那小孩会有一番伟大冒险，但转眼间biu地一声，人的一辈子就这样过去； 到一堆五彩斑斓的气球带着房子拔地而起的时候，我会心一笑，是呀，气球飞行，哪个少年没有过这样的梦呢。 那之后的故事却感觉有些……不协调，我不喜欢看老年人被... (展开)
410 24 106回应 收起
明珠一颗孙小美 2009-08-27 13:02:50

## 把秘密说成是玩笑

七夕的时候看电影实在不是一个好的选择，在我画着一个亮晶晶的大眼圈坐上一辆taxi的时候，年轻的的士司机有点兴奋，他说靓女情人节这么早就散场了啊，我低着头默默，nonono，活动才刚刚开始。半个小时之后，我的不忿完全的表达在脸上，某人亟不可待的电话一次次的响了起来，的... (展开)
177 18 94回应 收起
小凡 2009-08-05 20:11:07

## Only Love Can Break Your Heart

一部电影能做到连我都觉得俗套，那么它一定是没治了。 如果Finding Nemo也保持在你最喜欢的没有之一的动画片长达5年直到Wall-E的出现，如果你5年之中把它的台词熟得要吐了可是每次当你看到全世界的动物八卦着有一只小丑鱼穿过整个大海去找他的儿子那段，还是忍不住要红眼眶，... (展开)
108 4 22回应 收起
ordersunshine 2009-05-31 14:54:59

## 关于梦想 关于爱情 关于我们 依然选择相信

这篇影评可能有剧透

一部作品 无论长短 无论内容 只要观者感动了 就是一部好的作品 一个梦想 无论大小 无论实际 只要相信的坚持下去 就是最重要的实现 一段爱情 无论结果 无论怀念 只要彼此依偎着慢慢便老 就是幸福 一部如果可以 我会给她十颗星的电影 一部寥寥数笔 却如此温馨浪漫动人的表达... (展开)
146 8 67回应 收起

> 更多影评 3065篇

添加新讨论

## 讨论区 · · · · · ·

讨厌小胖子的留个言 | 来自张克岳 | 25 回应 | 2022-11-20 16:40:52
有些人真的很奇怪 | 来自solitude. | 1 回应 | 2022-11-19 21:10:27
为什么不把鸟交给老探险家呢 | 来自21世纪小恐龙 | 11 回应 | 2022-11-19 21:06:33
多年后再观影，意味全变了 | 来自豆友216927608 | 10 回应 | 2022-10-26 21:18:06
总觉得结尾太残忍 | 来自上界司命 | 111 回应 | 2022-10-10 14:09:32

> 去这部影片的讨论区（全部598条）

## 关于《飞屋环游记》的问题 · · · · · · ( 全部19个 )

- 关于snipe和squirrel的疑问？ 4人回答
- 谁有飞屋环游记催泪四分钟的截图拼图？？？？ 6人回答

> 全部19个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 芒果TV VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【内牛满面】 (影志)
- 【励志电影】 (影志)
- 【豆瓣高分动画长片】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 【爱看动画】 (影志)

## 谁在看这部电影 · · · · · ·

- Victor
  1分钟前 看过
- 勇敢叮当猫
  2分钟前 看过
- momo
  5分钟前 看过

2353643人看过 / 291093人想看

订阅飞屋环游记的评论:
feed: rss 2.0